@@ -22,8 +22,11 @@
 
 #include "kitinerary_export.h"
 
+#include <QString>
+
 #include <memory>
 #include <vector>
+
 template <typename T> class QSharedPointer;
 
 namespace KCalCore {
@@ -38,9 +41,9 @@ namespace KMime {
 class Content;
 }
 
+class QByteArray;
 class QDateTime;
 class QJsonArray;
-class QString;
 
 namespace KItinerary {
 
@@ -116,10 +119,10 @@ class PdfDocument;
  *   was received. This typically only needs a @c From: and @c Date: line, but can even be
  *   entirely empty (or non-existing) for structured data that does not need a custom extractor.
  *   This context information is applied to all tests in this folder.
- * - @c <testname>.[txt|html|pdf|pkpass|ics|eml|mbox]: The input test data.
- * - @c <testname.extension>.json: The expected JSON-LD output. If this file doesn't
+ * - @c \<testname\>.[txt|html|pdf|pkpass|ics|eml|mbox]: The input test data.
+ * - @c \<testname.extension\>.json: The expected JSON-LD output. If this file doesn't
  *   exists it is created by the test program.
- * - @c <testname.extension>.skip: If this file is present the corresponding test
+ * - @c \<testname.extension\>.skip: If this file is present the corresponding test
  *   is skipped.
  */
 class KITINERARY_EXPORT ExtractorEngine
@@ -133,9 +136,6 @@ public:
     /** Resets the internal state, call before processing new input data. */
     void clear();
 
-    /** Set the extractors to be run on the current data. */
-    [[deprecated]] void setExtractors(std::vector<const Extractor*> &&extractors);
-
     /** The text to extract data from.
      *  Only considered for text extractors.
      */
@@ -161,6 +161,13 @@ public:
      *  @p content is also set as extraction context (see setContext).
      */
     void setContent(KMime::Content *content);
+    /** Any kind of data to extract from.
+     *  ExtractorEngine tries to auto-detect what type of data this is
+     *  and pick one of the above methods accordingly.
+     *  Avoid using this if you know exactly what data you have.
+     *  @param fileName Used as a hint to determine the type, optional.
+     */
+    void setData(const QByteArray &data, const QString &fileName = {});
 
     /** Sets the MIME part the document we try to extract comes from.
      *  Use this for documents received by email, to provide additional
@@ -178,7 +185,7 @@ public:
      */
     void setContextDate(const QDateTime &dt);
 
-    /** Perform the actual extration, and return the JSON-LD data
+    /** Perform the actual extraction, and return the JSON-LD data
      *  that has been found.
      */
     QJsonArray extract();
